==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/BuildpackPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.BuildpackPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Buildpack properties payload
 * @property id Id of the buildpack
 */
public data class BuildpackPropertiesArgs(
    public val id: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.BuildpackPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.appplatform.inputs.BuildpackPropertiesArgs =
        com.pulumi.azurenative.appplatform.inputs.BuildpackPropertiesArgs.builder()
            .id(id?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BuildpackPropertiesArgs].
 */
@PulumiTagMarker
public class BuildpackPropertiesArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    /**
     * @param value Id of the buildpack
     */
    @JvmName("uasqafrkoodmvihi")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Id of the buildpack
     */
    @JvmName("ljnqtfsovyvjgvnf")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): BuildpackPropertiesArgs = BuildpackPropertiesArgs(
        id = id,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/BuildpackPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.BuildpackPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Buildpack properties payload
 * @property id Id of the buildpack
 */
public data class BuildpackPropertiesArgs(
    public val id: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.BuildpackPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.appplatform.inputs.BuildpackPropertiesArgs =
        com.pulumi.azurenative.appplatform.inputs.BuildpackPropertiesArgs.builder()
            .id(id?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BuildpackPropertiesArgs].
 */
@PulumiTagMarker
public class BuildpackPropertiesArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    /**
     * @param value Id of the buildpack
     */
    @JvmName("vegviodywfmfsygo")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Id of the buildpack
     */
    @JvmName("opfhpfeadkcypwmj")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): BuildpackPropertiesArgs = BuildpackPropertiesArgs(
        id = id,
    )
}
